@@ -639,3 +639,16 @@ def expand_line_clamp(base_url, name, tokens):
             raise InvalidValues
     else:
         raise InvalidValues
+
+
+@expander('text-align')
+def expand_text_align(base_url, name, tokens):
+    """Expand the ``text-align`` property."""
+    if len(tokens) == 1:
+        keyword = get_single_keyword(tokens)
+        align_all = 'justify' if keyword == 'justify-all' else keyword
+        yield 'text_align_all', align_all
+        align_last = 'start' if keyword == 'justify' else align_all
+        yield 'text_align_last', align_last
+    else:
+        raise InvalidValues
